To compute

```
acido-short.fa.sig.dump.txt
tr-2.fa.sig.dump.txt
tr-1.fa.sig.dump.txt
```

execute:

```
sourmash compute tr-1.fa tr-2.fa acido-short.fa
sourmash dump tr-1.fa.sig 
sourmash dump tr-2.fa.sig 
sourmash dump acido-short.fa.sig 
```
